pub struct MemRegionWithMappingInfo {
mem: MemoryMapping,
pub mapping_info: Vec<FileMappingInfo>,
}Expand description
Memory regions where ext2 metadata were written with information of mmap operations to be done.
Fields
mem: MemoryMappingmapping_info: Vec<FileMappingInfo>Implementations
Sourceimpl MemRegionWithMappingInfo
impl MemRegionWithMappingInfo
Sourcepub fn do_mmap(self) -> Result<MemoryMappingArena>
pub fn do_mmap(self) -> Result<MemoryMappingArena>
Do mmap and returns the memory region where ext2 was created.